@@ -38,40 +38,42 @@
     if (length(dc.code) > 1) {
         stopError("Multiple \"don't care\" codes found.")
     }
-    if (length(dc.code) > 0) {
-        colnms <- colnames(data)
-        data[] <- lapply(data, function(x) {
-            if (!inherits(x, "declared")) {
-                x <- as.character(x)
-                x[x == dc.code] <- -1
-                if (possibleNumeric(x)) {
-                    x <- asNumeric(x)
-                }                
-            }
-            return(x)
-        })
-        colnames(data) <- colnms
-    }
     fuzzy.cc <- logical(ncol(data))
     hastime <- logical(ncol(data))
     factor <- sapply(data, is.factor)
     declared <- sapply(data, function(x) inherits(x, "declared"))
-    pN <- sapply(data, possibleNumeric)
-    for (i in seq(ncol(data))) {
-        if (pN[i] & !declared[i]) {
-            copy.cc <- asNumeric(data[, i])
-            fuzzy.cc[i] <- any(na.omit(copy.cc) %% 1 > 0)
-            if (!fuzzy.cc[i] & !any(is.na(copy.cc))) {
-                if (any(na.omit(copy.cc) < 0)) {
-                    hastime[i] <- TRUE
-                    copy.cc[copy.cc < 0] <- max(copy.cc) + 1
-                }
-            }
-            data[, i] <- copy.cc
-        }
-    }
     noflevels <- getLevels(data)
     attributes(noflevels) <- NULL
+    for (i in seq(ncol(data))) {
+        cc <- data[, i]
+        label <- attr(cc, "label", exact = TRUE)
+        labels <- attr(cc, "labels", exact = TRUE)
+        if (is.factor(cc)) {
+            cc <- as.character(cc)
+        }
+        if (length(dc.code) > 0 && is.element(dc.code, cc)) {
+            cc[is.element(cc, dc.code)] <- -1
+        }
+        if (possibleNumeric(cc)) {
+            cc <- asNumeric(cc)
+            fuzzy.cc[i] <- any(na.omit(cc) %% 1 > 0)
+            if (!fuzzy.cc[i] & !anyNA(cc)) {
+                if (any(na.omit(cc) < 0)) {
+                    hastime[i] <- TRUE
+                    cc[cc < 0] <- max(cc) + 1 
+                }
+            }
+            if (declared[i]) {
+                if (min(cc) != 0 && !fuzzy.cc[i]) {
+                    cc <- recode(cc, paste(sort(labels), seq(noflevels[i]) - 1, sep = "=", collapse = ";"))
+                }
+                attr(cc, "label") <- label
+                attr(cc, "labels") <- labels
+                class(cc) <- c("declared", class(cc))
+            }
+            data[[i]] <- cc
+        }
+    }
     factor <- factor & !hastime
     categories <- list()
     columns <- colnames(data)
@@ -85,17 +87,21 @@
                 x <- data[, i]
                 labels <- attr(x, "labels", exact = TRUE)
                 if (is.null(labels)) {
-                    stopError("Declared columns should have labels for all values.")
+                    stopError("Declared columns should have labels.")
                 }
                 else {
-                    if (length(labels) != noflevels[i]) {
-                        stopError("All values should have declared labels.")
+                    if (noflevels[i] == 2) {
+                        if (length(labels) == 1) {
+                            stopError("Binary crisp columns should have labels for both presence and absence.")
+                        }
+                    }
+                    else { 
+                        if (length(labels) != noflevels[i]) {
+                            stopError("All multi-values should have declared labels.")
+                        }
                     }
                 }
-                attributes(x) <- NULL
-                data[, i] <- recode(x, paste(sort(labels), seq(noflevels[i]) - 1, sep = "=", collapse = ";"))
                 categories[[columns[i]]] <- names(sort(labels))
-                attr(categories, "labels") <- labels
             }
         }
     }
