@@ -1,4 +1,4 @@
-# Copyright (c) 2019 - 2022, Adrian Dusa
+# Copyright (c) 2019 - 2023, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -33,8 +33,12 @@
     scollapse <- if (is.element("scollapse", names(dots))) dots$scollapse else FALSE 
     if (identical(snames, "")) {
         syscalls <- unlist(lapply(sys.calls(), deparse))
-        if (any(withdata <- grepl("with\\(", syscalls))) {
-            data <- get(unlist(strsplit(gsub("with\\(", "", syscalls), split = ","))[1], envir = length(syscalls) - which(withdata))
+        usingwith <- "admisc::using\\(|using\\(|with\\("
+        if (any(usingdata <- grepl(usingwith, syscalls))) {
+            data <- get(
+                unlist(strsplit(gsub(usingwith, "", syscalls), split = ","))[1],
+                envir = length(syscalls) - tail(which(usingdata), 1)
+            )
             if (is.data.frame(data) | is.matrix(data)) {
                 snames <- colnames(data)
             }
